@@ -12,16 +12,20 @@
 # ;-)
 
 VERSION = '1.1.7'  # PIL version
-PILLOW_VERSION = '3.1.1'  # Pillow
+PILLOW_VERSION = '3.4.1'  # Pillow
+
+__version__ = PILLOW_VERSION
 
 _plugins = ['BmpImagePlugin',
             'BufrStubImagePlugin',
             'CurImagePlugin',
             'DcxImagePlugin',
+            'DdsImagePlugin',
             'EpsImagePlugin',
             'FitsStubImagePlugin',
             'FliImagePlugin',
             'FpxImagePlugin',
+            'FtexImagePlugin',
             'GbrImagePlugin',
             'GifImagePlugin',
             'GribStubImagePlugin',
